@@ -11,8 +11,6 @@
 # WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 # See the License for the specific language governing permissions and
 # limitations under the License.
-from __future__ import unicode_literals
-import platform
 from twine import package, exceptions
 
 import pretend
@@ -214,12 +212,6 @@ TWINE_1_5_0_WHEEL_HEXDIGEST = package.Hexdigest(
     'b657a4148d05bd0098c1d6d8cc4e14e766dbe93c3a5ab6723b969da27a87bac0',
 )
 
-if platform.python_implementation().lower() == 'pypy':
-    # pyblake2 refuses to install on PyPy
-    TWINE_1_5_0_WHEEL_HEXDIGEST = TWINE_1_5_0_WHEEL_HEXDIGEST._replace(
-        blake2=None,
-    )
-
 
 def test_hash_manager():
     """Verify our HashManager works."""
